@@ -22,7 +22,9 @@ class TestUtils(unittest.TestCase):
             line_points, line_direction, plane_points, plane_normals)
         for clip_length in clip_lengths:
             self.assertAlmostEqual(
-                clip_length, 1.0, msg="Projection through unity cube should give unity clip length")
+                clip_length,
+                1.0,
+                msg="Projection through unity cube should give unity clip length")
 
         line_direction = np.ascontiguousarray([1.0, 0.2, 0.1])
         line_direction = line_direction / np.linalg.norm(line_direction)
@@ -34,14 +36,14 @@ class TestUtils(unittest.TestCase):
                 1.0,
                 msg="Tilted projection through unity cube should give greater than unity clip length")
 
-    def test_lab_strain_to_lattice_matrix(self):
+    def test_lab_strain_to_B_matrix(self):
 
         U = Rotation.random().as_matrix()
         strain_tensor = (np.random.rand(3, 3) - 0.5) / \
             100.  # random small strain tensor
         strain_tensor = (strain_tensor.T + strain_tensor) / 2.
         unit_cell = [5.028, 5.028, 5.519, 90., 90., 120.]
-        B = utils.lab_strain_to_lattice_matrix(strain_tensor, U, unit_cell)
+        B = utils.lab_strain_to_B_matrix(strain_tensor, U, unit_cell)
 
         n_c = np.random.rand(3,)  # crystal unit vector
         n_c = n_c / np.linalg.norm(n_c)
@@ -106,11 +108,14 @@ class TestUtils(unittest.TestCase):
             msg="Error in diffractogram azimuth integration")
 
     def test_get_bounding_ball(self):
-        points = np.random.rand(4,3)-0.5
+        points = np.random.rand(4, 3) - 0.5
         centre, radius = utils.get_bounding_ball(points)
-        mean = np.mean(points,axis=0)
-        base_radius = np.max(np.linalg.norm(points-mean,axis=1))
-        self.assertLessEqual( radius, base_radius, msg="Ball is larger than initial guess")
+        mean = np.mean(points, axis=0)
+        base_radius = np.max(np.linalg.norm(points - mean, axis=1))
+        self.assertLessEqual(
+            radius,
+            base_radius,
+            msg="Ball is larger than initial guess")
 
         for p in points:
             self.assertLessEqual(
@@ -120,12 +125,16 @@ class TestUtils(unittest.TestCase):
 
         ratios = []
         for _ in range(500):
-            points = np.random.rand(4,3)-0.5
+            points = np.random.rand(4, 3) - 0.5
             centre, radius = utils.get_bounding_ball(points)
-            mean = np.mean(points,axis=0)
-            base_radius = np.max(np.linalg.norm(points-mean,axis=1))
-            ratios.append( radius / base_radius )
-        self.assertLessEqual(np.mean(ratios), 0.9, msg="Averag radius decrease less than 10%")
+            mean = np.mean(points, axis=0)
+            base_radius = np.max(np.linalg.norm(points - mean, axis=1))
+            ratios.append(radius / base_radius)
+        self.assertLessEqual(
+            np.mean(ratios),
+            0.9,
+            msg="Averag radius decrease less than 10%")
+
 
 if __name__ == '__main__':
     unittest.main()
