@@ -1,11 +1,9 @@
 """General package internal utility functions.
 """
-from re import L
 import sys
 
 import numpy as np
 from numba import njit
-from scipy.optimize import minimize, NonlinearConstraint
 from xrd_simulator.xfab import tools
 from CifFile import ReadCif
 
@@ -123,14 +121,14 @@ def alpha_to_quarternion(alpha_1, alpha_2, alpha_3):
                      sin_alpha_1 * np.cos(alpha_2)]).T
 
 
-def lab_strain_to_lattice_matrix(
+def lab_strain_to_B_matrix(
         strain_tensor,
         crystal_orientation,
         unit_cell):
-    """Take a strain tensor in crystal coordinates and produce the lattice matrix (B matrix).
+    """Take a strain tensor in lab coordinates and produce the lattice matrix (B matrix).
 
     Args:
-        strain_tensor (:obj:`numpy array`): Symmetric strain tensor in crystal
+        strain_tensor (:obj:`numpy array`): Symmetric strain tensor in lab
             coordinates. ``shape=(3,3)``
         crystal_orientation (:obj:`numpy array`): Unitary crystal orientation matrix.
             ``crystal_orientation`` maps from crystal to lab coordinates. ``shape=(3,3)``
@@ -139,7 +137,8 @@ def lab_strain_to_lattice_matrix(
             a,b and c are in units of anstrom.
 
     Returns:
-        (:obj:`numpy array`) Lattice matrix (B matrix)``shape=(3,3)``
+        (:obj:`numpy array`) B matrix, mapping from hkl Miller indices to realspace crystal
+        coordinates, ``shape=(3,3)``.
 
     """
     crystal_strain = np.dot(
@@ -241,7 +240,11 @@ def get_bounding_ball(points, epsilon=1e-7):
             return _get_circumsphere(points[R])
 
         c, r2 = _get_circumsphere(points[R[: points.shape[1] + 1]])
-        if np.all(np.fabs(np.sum((points[R] - c) ** 2, axis=1) - r2) < epsilon):
+        if np.all(
+            np.fabs(
+                np.sum(
+                    (points[R] - c) ** 2,
+                axis=1) - r2) < epsilon):
             return c, r2
 
     class Node(object):
@@ -277,5 +280,5 @@ def get_bounding_ball(points, epsilon=1e-7):
     points = points.astype(float, copy=False)
     root = Node(range(points.shape[0]), [])
     traverse(root)
-    c,r = root.D
-    return c, np.sqrt(r)
\ No newline at end of file
+    c, r = root.D
+    return c, np.sqrt(r)
